package
Version:
v0.0.0-...-9588fa0
Opens a new window with list of versions in this module.
Published: Sep 9, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func EncodeTypedPointer(buf *[]byte, vt *rt.GoType, vp *unsafe.Pointer, sb *vars.Stack, fv uint64) error
-
func Execute(b *[]byte, p unsafe.Pointer, s *vars.Stack, flags uint64, prog *ir.Program) error
-
func SetCompiler(c func(*rt.GoType, ...interface{}) (interface{}, error))
func SetCompiler(c func(*rt.GoType, ...interface{}) (interface{}, error))
Source Files
¶
Click to show internal directories.
Click to hide internal directories.